卢旺达饭店 (豆瓣)
Description: 卢旺达饭店电影简介和剧情介绍,卢旺达饭店影评、图片、预告片、影讯、论坛、在线购票
Keywords: 卢旺达饭店,Hotel Rwanda,卢旺达饭店影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.165豆瓣电影Top250

# 卢旺达饭店 Hotel Rwanda (2004)

导演: 特瑞·乔治
编剧: 凯尔·皮尔森 / 特瑞·乔治
主演: 唐·钱德尔 / 苏菲·奥康内多 / 华金·菲尼克斯 / 尼克·诺特 / 哈基姆·凯-卡西姆 / 托尼·戈罗奇 / 法纳·莫科纳 / 大卫·奥哈拉 / 莫苏西·麦格诺 / 西莫·莫加瓦扎 / 卡拉·西摩 / 罗伯托·西特兰 / 德斯蒙德·杜布 / 蕾乐蒂·库马洛
类型: 剧情 / 传记 / 历史 / 战争
官方网站: www.mgm.com/ua/hotelrwanda/main.html
制片国家/地区: 英国 / 南非 / 意大利 / 美国
语言: 英语 / 法语
上映日期: 2004-09-11(多伦多电影节) / 2005-03-04(英国)
片长: 121分钟
又名: 卢安达饭店(台)
IMDb: tt0395169
豆瓣评分
引用
8.9
311938人评价
5星
54.8%
4星
38.1%
3星
6.5%
2星
0.4%
1星
0.1%
好于 98% 战争片
好于 98% 历史片
想看 看过
评价:
推荐

## 卢旺达饭店的剧情简介 · · · · · ·

1994年卢旺达宣布独立后，胡图族与图西族两部族之间矛盾重重，多次发生冲突，战事持续不断。胡图族大肆屠杀图西族人，在这种背景下，卢旺达饭店经理保罗一直四面奔走，最终成功挽救了饭店里一千多名图西族和胡图族难民。 ©豆瓣

## 卢旺达饭店的演职员 · · · · · · ( 全部 28 )

- 特瑞·乔治 导演
- 唐·钱德尔 演员
- 苏菲·奥康内多 演员
- 华金·菲尼克斯 演员
- 尼克·诺特 演员
- 哈基姆·凯-卡西姆 演员

## 卢旺达饭店的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片392 · 添加 )

## 卢旺达饭店的获奖情况 · · · · · · ( 全部 )

- 第77届奥斯卡金像奖
- 最佳男主角(提名)
- 唐·钱德尔

- 第62届金球奖
- 电影类 最佳剧情片(提名)

- 第59届英国电影学院奖
- 电影奖 最佳原创剧本(提名)
- 凯尔·皮尔森 / 特瑞·乔治

## 喜欢这部电影的人也喜欢 · · · · · ·

  拯救大兵瑞恩

  黑鹰坠落

  穿条纹睡衣的男孩

  钢琴家

  辛德勒的名单

  兵临城下

  1917

  血战钢锯岭

  战争之王

  敦刻尔克

我要写短评

## 卢旺达饭店的短评 · · · · · · ( 全部 59669 条 )

热门 / 最新 / 好友

### 2528 有用 音五六// Jee Zark 看过 2011-02-04 14:14:05

很早以前看黑镜头就知道这段历史了 片中还是侧重于胡图族对图西族的屠杀 但实际上 在图西族控制的地区 对胡图族也发生着同样的杀戮 这是一场无法说清的事实 事实没有真相 只有荒谬的让人不可理解 人们用最原始的武器棍棒刀叉去和自己的邻居搏命 只因为他们觉得 不杀死对方对方就会来杀自己

### 1793 有用 蓓蕾 看过 2008-10-06 21:48:40

当这个世界闭上双眼，他却敞开了怀抱。

### 3508 有用 米米无 看过 2010-03-23 00:28:28

我们看了那些屠杀的镜头 然后继续吃大餐

### 979 有用 今天小熊不吃糖 看过 2008-12-12 23:05:04

我所听过的最美的片尾曲，震撼心灵的人性故事，愿真善永存，苦难和邪恶远离所有人

### 1064 有用 伊宜以忆 看过 2005-10-26 19:03:51

当电影成为我们铭记历史的唯一方式　是幸或不幸

> 更多短评 59669条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 卢旺达饭店的影评 · · · · · · ( 全部 938 条 )

热门 / 最新 / 好友
叶洲 2008-05-29 23:09:34

## 100万对我们来说只是数字

这篇影评可能有剧透

你不能想象，这是现代文明的20世纪末；你不能想象，在一整个国家，法律、道德、秩序、人性完全丧失殆尽；你不能想象，在一百天的时间里，100万人惨遭屠杀；你不能想象，面对这一惨剧，全世界竟然默不作声！ 本片完全依据真实事件改编。卢旺达这个非洲国家有两个主要民族，胡图... (展开)
2692 149 359回应 收起
奎斯Chris 2008-03-22 11:25:30

## 卢旺达、孩子和黑人

终于看完《卢旺达饭店》。非娱乐片，一次性看完，于我而言，是件稀罕的事。 喜爱这样一部影片，远胜过同年大热的《飞行家》，或者《百万宝贝》。 这是关乎一个男人的故事。关乎，爱与救赎。 许多时候，我都带着某种麻木的情绪。比如在看着片中反复出现的遍地尸体时，我几乎... (展开)
537 86 80回应 收起
Adam 2005-07-04 13:13:27

## 在人性危机中嘲讽

《卢旺达饭店》买了几个星期了，一直都没看，不是不舍得看，而是不敢看，因为知道这是一场人间惨剧，不知道电影会怎么来表达，面对每天繁忙的工作，不敢让自己的心情过于沉重，坚持到昨天晚上，才下决心看了。 看着电影，好几次，我禁不住都笑了，当然电影不是搞笑... (展开)
482 136 152回应 收起
飘渺游侠 2011-06-13 12:09:48

## 卢旺达大屠杀

昨天看完这部根据真人真事改编的电影，或者说是当年卢旺达大屠杀的某种形式的纪念品，内心久久难以平复。在1994年卢旺达发生了让全人类蒙羞的种族大屠杀，胡图族人在短短3个月时间内疯狂地屠杀了将近80-100万的图西族，约占整个国家八分之一的人口。影片是讲述是饭店经理保罗如... (展开)
319 10 41回应 收起
Pluto 2018-01-26 00:44:50

## 卢旺达屠杀的参考(我也不知道哪来的，只是觉得有参考价值)

1994年4月，非洲内陆小国卢旺达发生了惨绝人寰的种族屠杀，在3个多月大约100天的时间里，大批无辜平民被杀。死亡人数至今难以最终确定，有的说50万，有的说80万，有的说100万。绝大多数被杀害的是图西族。当大屠杀发生时，曾经有美国政治人物这样问道：“谁是好人？”，意思是... (展开)
214 27 74回应 收起
海棠朵朵 2006-03-11 22:54:22

## 《卢旺达饭店》——人性的仓皇

正沉浸在小崔几年前写的那本家常里短，轻松幽默又不乏认真严肃的《不过如此》时候，看了今年奥斯卡获奖影片《卢旺达饭店》，再也笑不起来了。小崔在书中谈到的关于日本的那一章节中提到：当人进入到一个群体时代之后，个人在“集体潜意识机制下，在心理上回产生一种本质性的变... (展开)
206 21 41回应 收起
繁星秋水 2009-01-27 00:19:21

## 泣血的非洲——《卢旺达饭店》

卢旺达大屠杀发生在1994年位于非洲中部的卢旺达，胡图族的政府军与图西族的卢旺达爱国阵线之间所发生的武装冲突，是一场有组织的大屠杀，也叫做卢旺达内战。当时据说在这场武装冲突中遇难人数超过一百万人。 ... (展开)
205 17 19回应 收起
捕手 2008-08-05 17:21:55

## 卢旺达种族大屠杀背景补充

国名：卢旺达共和国（The Republic of Rwanda） 独立日：7月1日（1962年） 国庆日：7月1日（1962年） 国旗：2002年1月1日开始使用新国旗。 自然地理：面积为26338平方公里。位于非洲中东部赤道两侧，内陆国家。西和西北与刚果（金）为邻，北与乌干达接壤，东与坦桑尼亚... (展开)
93 5 6回应 收起
Jean 2005-11-22 14:12:35

## The Abyss

Nowadays, gory scenes that depicted a battle or a human tragedy in Hollywood have become as trendy as the obnoxious white wires sticking out of ipod user’s ears on a San Francisco bus. Started with Saving Private Ryan, directors competing to win the most r... (展开)
124 21 29回应 收起
iliqing 2006-03-04 22:49:47

## Million Voices的歌词（片尾插曲）

Wyclef Jean - Million Voices African Chorus throughout song: ----------------------------------- Ni dyar'izuba, Rizagaruka, Hejuru yacu, Ni nduzaricyeza ricyeza. [When will the sun return above us?] [Who will reveal it once again to us?] -----------------... (展开)
37 4 10回应 收起

> 更多影评 938篇

添加新讨论

## 讨论区 · · · · · ·

14年后真相揭秘：引发卢旺达种族大屠杀的元凶到底... | 来自Loong_Wang | 126 回应 | 2022-11-17 10:29:16
大家都在说不要种族歧视 然后反口一句白人去死吧 | 来自陆续你们一个个 | 4 回应 | 2022-11-03 21:18:48
看了热门短评，我想说 | 来自柯里昂 | 3 回应 | 2022-10-23 22:58:38
男主角的妻子真是一朵黑莲花 | 来自里昂杨 | 5 回应 | 2022-10-23 22:48:18
不干净的评论区 | 来自EVa🍥 | 3 回应 | 2022-10-09 14:41:15

> 去这部影片的讨论区（全部176条）

## 关于《卢旺达饭店》的问题 · · · · · · ( 全部9个 )

- 中间为什么联合国撤军，说保罗是个骗子？ 10人回答
- 保罗那个将军靠山最后凭什么就肯帮他了呢，没太看懂？ 7人回答

> 全部9个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 真实案件精选 ([己注销])

## 谁在看这部电影 · · · · · ·

- 沉默是最好的
  刚刚 想看
- 再见白丝
  1分钟前 想看
- 现在时间上午十
  4分钟前 想看

488752人看过 / 321309人想看

订阅卢旺达饭店的评论:
feed: rss 2.0